@@ -1,13 +1,17 @@
 package Log::Any::IfLOG;
 
-our $DATE = '2015-03-24'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 sub import {
     my $self = shift;
 
     my $caller = caller();
-    if ($ENV{LOG}) {
+
+    my $log_enabled = $ENV{LOG} || $ENV{TRACE} || $ENV{DEBUG} ||
+        $ENV{VERBOSE} || $ENV{QUIET} || $ENV{LOG_LEVEL};
+
+    if ($log_enabled) {
         require Log::Any;
         Log::Any->_export_to_caller($caller, @_);
     } else {
@@ -24,7 +28,7 @@ sub new { my $o = ""; bless \$o, shift }
 sub AUTOLOAD { 0 }
 
 1;
-# ABSTRACT: Load Log::Any only if LOG environment variable is true
+# ABSTRACT: Load Log::Any only if log-related environment variables are set
 
 __END__
 
@@ -34,11 +38,11 @@ __END__
 
 =head1 NAME
 
-Log::Any::IfLOG - Load Log::Any only if LOG environment variable is true
+Log::Any::IfLOG - Load Log::Any only if log-related environment variables are set
 
 =head1 VERSION
 
-This document describes version 0.02 of Log::Any::IfLOG (from Perl distribution Log-Any-IfLOG), released on 2015-03-24.
+This document describes version 0.03 of Log::Any::IfLOG (from Perl distribution Log-Any-IfLOG), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -46,16 +50,18 @@ This document describes version 0.02 of Log::Any::IfLOG (from Perl distribution
 
 =head1 DESCRIPTION
 
-This module will load L<Log::Any> only when C<LOG> environment variable is true.
-Otherwise, the module is not loaded and if user imports C<$log>, a dumb object
-will be returned instead that will accept any method but return false.
+This module will load L<Log::Any> only when C<LOG> environment variable is true
+(or C<TRACE>, or C<DEBUG>, or C<VERBOSE>, or C<QUIET>, or C<LOG_LEVEL>; these
+variables are used by L<Perinci::CmdLine>). Otherwise, the module is not loaded
+and if user imports C<$log>, a dumb object will be returned instead that will
+accept any method but return false.
 
 This is a quick-hack solution to avoid the cost of loading Log::Any under
-"normal condition" (when C<LOG> is not set to true). Since Log::Any 1.00,
-startup overhead increases to about 7ms on my PC (from under 1ms for the
-previous version). Since I want to keep startup overhead of CLI apps under 50ms
-(see L<Perinci::CmdLine::Lite>) to keep tab completion from getting a noticeable
-lag, every millisecond counts.
+"normal condition" (when log-enabling variables/flags are not set to true).
+Since Log::Any 1.00, startup overhead increases to about 7ms on my PC (from
+under 1ms for the previous version). Since I want to keep startup overhead of
+CLI apps under 50ms (see L<Perinci::CmdLine::Lite>) to keep tab completion from
+getting a noticeable lag, every millisecond counts.
 
 =for Pod::Coverage ^(.+)$
 
@@ -66,6 +72,20 @@ lag, every millisecond counts.
 If set to true, will load Log::Any as usual. Otherwise, won't load Log::Any and
 will return a dumb object in C<$log> instead.
 
+=head2 TRACE => bool
+
+=head2 DEBUG => bool
+
+=head2 VERBOSE => bool
+
+=head2 QUIET => bool
+
+=head2 LOG_LEVEL => str
+
+These variables are used by L<Perinci::CmdLine> as a shortcut to set log level.
+The setting of these variables indicate that user wants to see some logging, so
+Log::Any will be loaded under the presence of these variables.
+
 =head1 SEE ALSO
 
 L<Log::Any>
